#
# spec file for package gpm
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           gpm
%define lname	libgpm2
Version:        1.20.7
Release:        22.1
Summary:        Console Mouse Support
License:        GPL-2.0-or-later AND GPL-3.0-or-later
Group:          System/Console
URL:            http://linux.schottelius.org/gpm/

Source0:        http://www.nico.schottelius.org/software/gpm/archives/gpm-%{version}.tar.lzma
Source2:        gpm.service
Source3:        sysconfig.mouse-%{name}
Source4:        README.SUSE
Source5:        baselibs.conf
Source6:        inputattach.c
Source7:        gpl-2.0.txt
Patch0:         gpm-DESTDIR.patch
Patch4:         gpm-syn_conf.patch
Patch6:         gpm-conf.patch
Patch7:         gpm-va_arg.patch
Patch9:         gpm-no_templates_for_new_multiple_mode.patch
Patch10:        gpm-ceil.patch
Patch11:        gpm-Gpm_Open.patch
Patch12:        gpm-daemon_mode.patch
Patch15:        gpm-verbosity.patch
Patch17:        gpm-log.patch
Patch18:        gpm-glibc210.patch
Patch19:        gpm-use_getdtablesize.patch
Patch20:        gpm-int_ptr_casts.patch
Patch21:        gpm-close-fds.patch
Patch23:        gpm-lib-silent.patch
Patch25:        gpm-multilib.patch
Patch26:        gpm-weak-wgetch.patch
#PATCH-FIX-UPSTREAM Pass path to gpm.h
Patch28:        gpm-dependencies.patch
#PATCH-FIX-UPSTREAM Create the symlink libgpm.so
Patch29:        gpm-do_create_symlink.patch
#PATCH-FIX-UPSTREAM Copy the current licence text from gpl-2.0+ to gpm.h
Patch30:        gpm-fix_fsf_addess.patch
#PATCH-FIX-UPSTREAM Fix missing declarations
Patch31:        decls.patch
Patch32:        gpm-fno-common.patch
BuildRequires:  bison
BuildRequires:  libtool
BuildRequires:  lzma
BuildRequires:  makeinfo
BuildRequires:  ncurses-devel
BuildRequires:  systemd-rpm-macros
Requires(pre):  %install_info_prereq
Requires(pre):  /bin/sed
Requires(pre):  %fillup_prereq
%{?systemd_requires}
Provides:       select
%ifarch ppc64
# bug437293
Obsoletes:      gpm-64bit
%endif

%description
The gpm (general purpose mouse) daemon is a mouse server for
applications running on the Linux console. It provides cut and paste
operations. If a gpm-aware program, such as mc (Midnight Commander)
or w3m (a text-based web browser), is active, they will use to gpm to
receive mouse events and do custom handling.

%package -n %lname
Summary:        Console mouse support library
License:        GPL-2.0-or-later
Group:          System/Libraries

%description -n %lname
This package provides a library that handles mouse requests and
delivers them to applications. See the description for the "gpm"
package for more information.

%package devel
Summary:        Development files for gpm (Console Mouse Support)
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
Development files for the gpm (general purpose mouse) package.

%prep
%setup -q
%patch -P 0
%patch -P 4
%patch -P 6
%patch -P 7
%patch -P 9
%patch -P 10
%patch -P 11
%patch -P 12
%patch -P 15
%patch -P 17
%patch -P 18
%patch -P 19
%patch -P 20
%patch -P 21
%patch -P 23
%patch -P 25
%patch -P 26
%patch -P 28
%patch -P 29
%patch -P 30
%patch -P 31 -p1
%patch -P 32 -p1
cp %{S:2} %{S:3} %{S:4} .
cp %{S:7} COPYING

%build
# This package failed when testing with -Wl,-as-needed being default.
# So we disable it here, if you want to retest, just delete this comment and the line below.
#export SUSE_ASNEEDED=1
NOCONFIGURE=1 ./autogen.sh
autoreconf -fi
export CFLAGS="%{optflags} -DQUIET_LIBGPM -D_REENTRANT -std=gnu11"
%configure --disable-static \
	--sysconfdir=%{_sysconfdir}/gpm
make CC=gcc %{?_smp_mflags}
gcc %{optflags} -o inputattach %{SOURCE6}

%install
make install DESTDIR="%buildroot" ROOT=""
#
# gpm confings
install -d %{buildroot}%{_sysconfdir}/${file/conf\/gpm-/gpm\/}
for file in conf/gpm-* ; do
  install -d %{buildroot}%{_sysconfdir}/${file/conf\/gpm-/gpm\/}
  install -m 644 $file %{buildroot}%{_sysconfdir}/${file/conf\/gpm-/gpm\/}
done
#
# lisp
# an updated version is part of emacs now
#install -d %%{buildroot}/usr/share/emacs/site-lisp
#install contrib/emacs/t-mouse.el* %%{buildroot}/usr/share/emacs/site-lisp
#
# start script
install -m 755 -d %{buildroot}%{_fillupdir}
install -m 755 -d %{buildroot}/%{_unitdir}
install -m 755 -d %{buildroot}/usr/sbin
install -m 755 inputattach %{buildroot}%{_sbindir}
install -m 644 sysconfig.mouse-%{name} %{buildroot}%{_fillupdir}
install -m 644 %{S:2} %{buildroot}/%{_unitdir}/gpm.service
%if 0%{?suse_version} < 1600
ln -sf %{_sbindir}/service %{buildroot}/usr/sbin/rcgpm
%endif
# there were two variables with the same value GPM_PROTOCOL and MOUSETYPE
# in SuLi 8.2. The MOUSETYPE variable better conforms with with other
# variable names MOUSEDEVICE and XMOUSETYPE name scheme, so get rid of
# the obsolete GPM_PROTOCOL variable
if grep "^GPM_PROTOCOL=" %{_sysconfdir}/sysconfig/mouse 1>/dev/null 2>/dev/null ; then
  if grep "^MOUSETYPE=" %{_sysconfdir}/sysconfig/mouse 1>/dev/null 2>/dev/null ; then
    # comment out the obsolete MOUSETYPE variable
    perl -pi -e "s|^(MOUSETYPE=.*)$|\#\$1     \# the variable GPM_PROTOCOL was renamed to MOUSETYPE|" %%{_sysconfdir}/sysconfig/mouse
  fi
  # rename GPM_PROTOCOL to MOUSETYPE
  perl -pi -e "s|^GPM_PROTOCOL=(.*)$|\# the variable GPM_PROTOCOL was renamed to MOUSETYPE\nMOUSETYPE=\$1|" %%{_sysconfdir}/sysconfig/mouse
fi

# Do not package static library
rm -fv %{buildroot}/%{_libdir}/libgpm.a
mkdir -p %{buildroot}/run
touch %{buildroot}/run/gpm.pid

%pre
%service_add_pre gpm.service

%preun
%service_del_preun gpm.service

%post
%{fillup_only gpm}
%service_add_post gpm.service
%{fillup_only -an mouse}
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz
%service_del_postun gpm.service

%post -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files
%defattr(-,root,root)
%license COPYING
%doc README README.gpm2 README.SUSE TODO
%doc doc/Announce doc/FAQ doc/README* doc/changelog
%{_infodir}/*
%{_mandir}/*/*
%dir %config %{_sysconfdir}/gpm
%config %{_sysconfdir}/gpm/*
%{_unitdir}/gpm.service
%{_bindir}/*
%{_sbindir}/*
%{_fillupdir}/*
%ghost /run/gpm.pid

%files -n %lname
%defattr(-,root,root)
%_libdir/libgpm.so.2*

%files devel
%defattr(-,root,root)
%{_includedir}/gpm.h
%{_libdir}/libgpm.so

%changelog
* Fri Mar 21 2025 Richard Biener <rguenther@suse.com>
- Use -std=gnu11 to avoid the C23 default of GCC 15 which no longer
  supports calling unprototyped functions.
* Wed Jan 22 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Drop rcFOO symlinks for CODE16 (PED-266).
* Tue Feb 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Oct 15 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * gpm.service
* Wed Mar 10 2021 Adam Majer <adam.majer@suse.de>
- remove unnecessary StandardOutput override in the unit definition
  file. (bsc#1182147)
* Wed Jan 15 2020 Adam Majer <adam.majer@suse.de>
- gpm-fno-common.patch: fix compilation in Tumbleweed (bsc#1160873)
* Thu Jan  9 2020 Jean Delvare <jdelvare@suse.com>
- Add back support for the TAOS evaluation module to inputattach.
* Tue Mar 27 2018 kukuk@suse.de
- Use %%license instead of %%doc [bsc#1082318]
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Mon Sep 11 2017 jengelh@inai.de
- Update description and remove two unnecessary ldconfig calls.
* Wed Jul  5 2017 schwab@suse.de
- decls.patch: fix missing declarations
* Mon Jun 12 2017 adam.majer@suse.de
- synced SLE .changes into devel project (bnc#1041340)
* Fri Jan 22 2016 pth@suse.de
- Remove dependency on aaa_base as using %%{_sysconfig} instead of
  hardcoded /etc shuts up rpmlint.
- Use %%{buildroot} and %%{optflags} insead of env vars.
* Wed Jan 13 2016 pth@suse.de
- Add %%post and %%postun entries for libgpm2.
- Add a current version  of GPL-2.0 with valid FSF address.
- Add gpm-fix_fsf_addess.patch to get the current FSF address into
  gpm.h.
* Thu Jul  9 2015 werner@suse.de
- Make libgpm able to handle ncurses ABI 6
* Tue Apr 14 2015 jengelh@inai.de
- Update license: the only GPL3 parts found are in the scripts/
  directory, which is not packaged.
* Wed May 21 2014 jsegitz@novell.com
- added necessary macros for systemd files
* Tue May 13 2014 nadvornik@suse.com
- install gpm.service with mode 644 (bnc#877455)
* Sat Apr  5 2014 dimstar@opensuse.org
- Install gpm.service without executable bit. The service files are
  never 'started'. This silences a warning in journal:
  systemd[1]: Configuration file /usr/lib/systemd/system/gpm.service
  is marked executable. Please remove executable permission bits.
  Proceeding anyway
* Wed Mar 26 2014 jengelh@inai.de
- Implement shlib packaging guidelines: new libgpm2 subpackage
- Add missing %%pre scriptlet
* Mon Dec  2 2013 coolo@suse.com
- don't buildrequire systemd, we just need the macros
* Mon Oct 28 2013 p.drouand@gmail.com
- Add systemd support and drop sysvinit support
- Change pid directory for new standard one
- Fix suse-wrong-suse-capitalisation rpmlint warning
* Mon Apr 22 2013 cfarrell@suse.com
- license update: GPL-2.0+ and GPL-3.0+
  Scripts git-archive-tarbz2.sh and report_success.sh are GPL-3.0+ licensed
* Tue Apr 16 2013 pth@suse.de
- Add software URL.
- Remove the patches tarball as upstream doesn't provide it anymore.
* Tue Apr 16 2013 pth@suse.de
- Update to 1.20.7:
- Adapt patches to changed sources.
- Add patch to pass the directory for gpm.h when generating
  dependencies: gpm-dependencies.patch
- Add patch that enables the creation of the libgpm.so symlink
  again and installs it: gpm-do_create_symlink.patch
- Removed patches not needed anymore:
  gpm-gcc4.3.patch
  gpm-libtool.patch
  config-guess-sub-update.patch
* Tue Feb 12 2013 schwab@suse.de
- config-guess-sub-update.patch:
  Update config.guess/sub for aarch64
* Thu Jan 10 2013 jengelh@inai.de
- Remove obsolete/undesired tags/sections
- Use more robust make install call
* Sat Oct 15 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Fri Sep 30 2011 uli@suse.com
- cross-build fix: use %%__cc macro
* Thu Jan 27 2011 pth@suse.de
- Through out the PS/2 patches that lead to gpm not working.
- Add patches from Fedora.
* Tue Oct 26 2010 cristian.rodriguez@opensuse.org
- Own gpm pid file but %%ghost it
* Wed Sep  8 2010 pth@suse.de
- Fix patches.
* Wed Sep  8 2010 pth@suse.de
- Update to latest stable version 1.20.6. Notable changes since
  1.20.1:
  * Fix default handler in liblow.c
  * Fixed SONAME (praise the Debian guys, Jonathan Nieder)
  * Fix possible segfault (FD_SET/negative)
  * Allow specifying ELISP variable on commandline
  * Fix broken code semantics
  * Fix socklen_t issue: Require posix header
  * Fix building with glibc 2.8
  * Updated library to version 2.1.0
  * Gpm_GetLibVersion behaves more consistent (all numbers are one or two digits)
- Remove version number from patch name.
- Adapt and clean out patches.
- Split out contained patches to a separate tar ball as not to
  confuse quilt.
- Use lzma instead of bzip2 to compress tarball.
* Tue Sep  7 2010 aj@suse.de
- Split up devel package, do not package static library.
- Remove support for updating from SUSE Linux 8.2.
* Sun Jan 10 2010 coolo@novell.com
- add baselibs.conf as source
* Fri Jun 19 2009 coolo@novell.com
- disable as-needed for this package as it fails to build with it
* Thu Jun 11 2009 coolo@novell.com
- fix build with glibc 2.10
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Mon Nov 24 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Fri Aug 22 2008 ro@suse.de
- remove deprecated option from fillup_and_insserv
* Mon Aug 11 2008 anosek@suse.cz
- fixed gpm not enabled at all run levels (bnc#340646)
  - enabled gpm also for runlevel 5 in /etc/init.d/gpm
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Apr  9 2008 anosek@suse.cz
- fixed: gpm spams /var/log/messages (bnc#307209) (log.patch)
* Thu Feb 21 2008 crrodriguez@suse.de
- add missing calls to restart_on_update and stop_on_removal macros
- update obsolete XUnitedLinux tags in the init script
* Wed Dec 12 2007 rguenther@suse.de
- use FOPEN_MAX instead of OPEN_MAX to fix build.
* Tue Aug  7 2007 anosek@suse.cz
- fixed /etc/sysconfig/mouse should configure the mouse by default for gpm
  [#262749]
  * modified sysconfig.mouse-gpm accordingly
* Thu May 24 2007 schwab@suse.de
- Don't install t-mouse.el, part of emacs now.
* Mon Mar 26 2007 rguenther@suse.de
- add bison BuildRequires
* Thu Mar 22 2007 rguenther@suse.de
- add ncurses-devel BuildRequires
* Tue Feb 27 2007 prusnak@suse.cz
- verbosity.patch [#247230]
  * removed -V option from documentation (not supported anymore)
  * silented error when -V provided on command-line
* Tue Feb 13 2007 anosek@suse.cz
- fixed libgpm.so.1 is not owned by any package [#244447]
  (gpm-1.20.1.patch)
* Thu Jan  4 2007 anosek@suse.cz
- fixed twiddler.c:334: warning: operation on 'ptr' may be
  undefined (warnings.patch)
* Thu Feb 16 2006 mmarek@suse.cz
- merge rcgpm-error-messages.diff into rcgpm
- hint users to run 'yast mouse' to configure gpm
  [#114919 and duplicates]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Nov  3 2005 mmarek@suse.cz
- fix apparent typo in gunze touchscreen driver [#132053]
* Tue Aug 23 2005 pmladek@suse.cz
- fixed the init script to print error messages if there are any
  problems with configuration [#106700]
* Sat Apr  9 2005 aj@suse.de
- Fix build also on i386 with GCC 4.
* Sat Mar 26 2005 aj@suse.de
- Fix build with GCC 4.
* Thu Mar 24 2005 uli@suse.de
- fixed to build on ARM
* Wed Nov 10 2004 ro@suse.de
- fixed file list
* Fri Mar  5 2004 mcihar@suse.cz
- fix possible segfault in Gpm_Open (bug #31970)
* Fri Oct 17 2003 mcihar@suse.cz
- do not build as root
* Mon Sep 15 2003 mcihar@suse.cz
- allow to set gpm repeating in sysconfig (GPM_REPEAT)
* Thu Aug 14 2003 mcihar@suse.cz
- added activation metadata to sysconfig template (bug #28903)
* Fri Jun 20 2003 ro@suse.de
- added directories to filelist
* Thu Apr 24 2003 ro@suse.de
- merged postuns
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Fri Mar 14 2003 pmladek@suse.cz
- redirected stdin, stdout and stderr to /dev/null in the daemon mode [#25386]
* Tue Mar  4 2003 pmladek@suse.cz
- fixed Gpm_Open to initialize option.consolename only for the first time
  (Gpm_Open.patch) [#24587]
* Mon Feb 17 2003 mmj@suse.de
- Use %%install_info macros [#23421]
* Thu Jan  9 2003 pmladek@suse.cz
- updated to the stable version 1.20.1:
  * synaptics ps2 touchpad support
  * code cleanup in various main files
  * prototype of mouse support for n-mice. expect final in 1.20.3.
- removed the obsolete compat patch which fixed compactibility with an older
  libgpm.so.1
- removed the obsolete synaptic patch which fixed synaptics.c to read
  /etc/gpm/syn.conf with TABs
- removed the obsolete old_pid_file patch which fixed the start of gpm server
  when an old invalid /var/run/gpm.pid exists
- removed the prototype of mouse support for n-mice, because it does not work
  for the present and it is uncomplete, it requires to define the mouse device
  before the mouse type on the command line, but the option -M is still needed,
  so this feature is not complete and can confuse the user
  (no_templates_for_new_multiple_mode.patch)
- fixed the default gpm/syn.conf according to the new synaptics.c
- fixed to link with "-lm" if needed (ceil is not an inline function)
  and where needed (gpm, libgpm.so)
* Thu Jan  2 2003 pmladek@suse.cz
- added metadata to the sysconfig template [#22660]
- got rid of the variable GPM_PROTOCOL from the init script and the
  sysconfig template, used MOUSETYPE instead (both variables were generated
  by YaST in SuLi 8.2, which is confusing and the variable MOUSETYPE
  better conforms with other variable names MOUSEDEVICE and XMOUSETYPE)
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Mon Sep  2 2002 kukuk@suse.de
- Remove unused yacc from neededforbuild
- Move rcgpm symlink to the same location as the binary is
- Remove not existent services from init script header
* Tue Aug 13 2002 pmladek@suse.cz
- already enabled __os_install_post macro
* Mon Aug 12 2002 pmladek@suse.de
- fixed problem with variable argument lists [#17528]
- removed patch which fixes messages, they are completely disabled
  in libgpm now, generally, no library should write messages on
  standart output or standart error output (it made problems
  with w3m for example)
* Tue Jul 30 2002 ro@suse.de
- also rename MOUSE to MOUSEDEVICE on update
- added PreReqs
* Tue Jul 30 2002 pmladek@suse.cz
- used the MOUSEDEVICE variable instead of the MOUSE variable [#17266]
- the MOUSEDEVICE variable is filled up into /etc/sysconfig/mouse
  by this package now [#17266]
* Thu Jul 25 2002 pmladek@suse.cz
- fixed compactibility with older libgpm.so.1
- fixed gpm messages:
  * added prefix "gpm: "
  * disabled debug messages in libgpm
  * improved message in function Gpm_Open when gpm server
  is not running
* Thu Jul 11 2002 pmladek@suse.cz
- added Silitek mouse drivers created by Dr. Werner Fink <werner@suse.de>
- gpm config files changes:
  * installed gpm-twiddler.conf, many thanks to Dr. Werner Fink for hint
  * fixed and installed gpm-syn.conf
  * moved all gpm config files from /etc to /etc/gpm
  * removed prefix "gpm-" from gpm config file names
  * created README.SuSE
  * improved "probe" part in init script to check changes
  in config files from /etc/gpm/*
- fixed synaptics.c to read /etc/gpm/syn.conf with TABs
- fixed support for reconnection for PS/2 mouses to save necessary values
  in struct mouse_features (to work correctly with dual-mouse stuff)
* Wed Jul 10 2002 pmladek@suse.cz
- updated to version 1.20.1rc1:
  * synaptics ps2 touchpad support
  * removed compile problems
  * objdir/ support without problems
  * cleaned up internal message functions
  * clean {g,m,}awk support
  * clean ps2 initialization (allows using ps2 mouse after you
  used synps!)
  * gpm clients can't cause gpm do die.
- removed obsolete patch for gpm-root.y
- removed obsolete ia64 patch
- removed obsolete Werner's patch for devfs.c
- improved patch for reconnection of PS/2 mouses
- fixed start of gpm server when an old invalid /var/run/gpm.pid exists
- reorganized patches
- used %%run_ldconfig macro in %%post and %%postun sections
- fixed init script according to skeleton
* Tue Jul  9 2002 werner@suse.de
- Bug fix in devfs.c for twid and other keyboards
- Bug fix in gpm.c: Some PS/2 devices really wants be readed
  byte by byte
- Complete the PS/2 command bytes in headers/defines.h
* Fri Mar 15 2002 kukuk@suse.de
- fix typo in sysconfig.gpm [Bug #15034]
* Thu Jan 17 2002 pmladek@suse.cz
- added variable GPM_PROTOCOL to /etc/sysconfig/mouse
- if the variable GPM_PARAM is empty then gpm will start with option
  "-t $GPM_PROTOCOL -m $MOUSE" now
* Wed Jan 16 2002 ro@suse.de
- removed setup.selection
* Fri Jan 11 2002 pmladek@suse.cz
- used macro %%{_libdir} to fix for lib64
- fixed rights of static library to 644
- fixed documentation in /usr/share/doc/packages/gpm
* Tue Jan  8 2002 egmont@suselinux.hu
- removed colons from init script messages
* Tue Jan  8 2002 ro@suse.de
-  moved GPM_PARAM to /etc/sysconfig/mouse
* Mon Dec 10 2001 pmladek@suse.cz
- updated to version 1.19.6:
  * Synaptics 4 Button Touchpad support
  * IntelliMouse Explorer support
  * some bug fixes
- removed obsolete mktemp security patch
* Wed Dec  5 2001 ro@suse.de
- add "-p" to macro call to deactivate perl-hack
* Wed Dec  5 2001 ro@suse.de
- use fillup_and_insserv and removed START_GPM
- move variable GPM_PARAM to this package
* Thu Oct 18 2001 pmladek@suse.cz
- fixed permissions of /dev/gpmctl back to 777, thus the
  applications (mc) can use mouse support for normal user (#11893)
* Mon Sep 17 2001 pmladek@suse.cz
- fixed to detect tokens AA 00 only in protocols
  for ps/2 mouses
* Mon Sep 10 2001 pmladek@suse.cz
- fixed to read only two bytes when mouse is
  reconected and it sends tokens AA 00
* Fri Sep  7 2001 pmladek@suse.cz
- fixed detection of reconnection of ps2 mouses and friends
  with kernel 2.4.9 or higher (bug #9822)
  * I take inspiration in patch from
    George Staikos (staikos@0wned.org)
* Thu Aug 23 2001 pmladek@suse.cz
- updated to version 1.19.3:
  * security fixes:
  * close the newly accept()ed socket in case of
  identification failure
  * removed initial setuid(0) call
  * added initgroups()
  * many bugfixes
  * features:
  * re-check console size on console change
  * changed use of -o option
- removed obsolete security patches
- removed obsolete resize patch
- applied two patches from RedHat:
  * fix permissions on /dev/gpmctl
  * call initgroups in gpm-root before spawning command as user
  * make gpm-root work on big endian
* Mon Aug  6 2001 kukuk@suse.de
- Fix comment about init script location [Bug #9494]
* Thu Jun 14 2001 pmladek@suse.cz
- fixed link libgpm.so.1
* Fri Jun  8 2001 kukuk@suse.de
- Use _libdir macros
* Fri Jun  8 2001 pmladek@suse.cz
- fixed to compile on sparc64 (libraries in /usr/lib64 now)
- fixed BUILD_ROOT
* Wed May 16 2001 pmladek@suse.cz
- fixed cast warnings on ia64
* Mon Apr 23 2001 pmladek@suse.cz
- fixed warnings on ia64
* Thu Apr 12 2001 pmladek@suse.cz
- fixed init script by new skeleton
- fixed to compile
  - removed include $(DEPS) from makefile
* Mon Jan 15 2001 nadvornik@suse.cz
- added Required-Start: $remote_fs $syslog [bug #5580]
* Mon Jan  1 2001 olh@suse.de
- add script name to %%postin
* Wed Dec 20 2000 pthomas@suse.de
- Fix bug in Gpm_Wgetch
* Tue Nov 28 2000 ro@suse.de
- sbin/init.d -> etc/init.d
* Wed Nov 22 2000 nadvornik@suse.cz
- removed runlevel links
- fixed init script
* Mon Oct  9 2000 nadvornik@suse.cz
- fixed Copyright
- used bzip2
* Fri Oct  6 2000 schwab@suse.de
- Use getdtablesize() instead of OPEN_MAX.
* Mon Jul 17 2000 nadvornik@suse.cz
- added security patch for disable-paste. Now it don't
  need to be installed with suid root.
* Thu Apr 27 2000 nadvornik@suse.cz
- added initgroups() patch
- used --sysconfdir=/etc
* Tue Apr 18 2000 nadvornik@suse.cz
- added BuildRoot
* Mon Apr  3 2000 uli@suse.de
- merged in gpm-root fix by Alessandro Rubini
* Fri Feb 25 2000 kukuk@suse.de
- Move /usr/{info,man} -> /usr/share/{info,man}
* Mon Jan 31 2000 uli@suse.de
- added fix for possible /tmp race attacks by thomas@suse.de
* Thu Dec 16 1999 ro@suse.de
- removed params for ldconfig (-l does not work any more)
- update to 1.18.1
- got rid of Makefile.Linux
- use RPM_OPT_FLAGS for configure
* Mon Oct 11 1999 uli@suse.de
- update -> 1.18.0
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Mar 16 1999 ro@suse.de
- fixed rc-script: check if gpm already running
* Fri Mar  5 1999 ro@suse.de
- fixed rc script
* Tue Mar  2 1999 ro@suse.de
- update to 1.17.5
* Mon Dec  7 1998 ro@suse.de
- updated init-script
- added rcgpm symlink
* Fri Oct 24 1997 florian@suse.de
- update to gpm 1.13
* Sun May  4 1997 bs@suse.de
- added /var/adm/setup/setup.selection
* Wed Apr 30 1997 florian@suse.de
- update to version 1.12
* Thu Jan  2 1997 florian@suse.de
- move startup scripts from aaa_base to gpm.tgz
